Struct rocket4::fairing::Info

source ·
pub struct Info {
    pub name: &'static str,
    pub kind: Kind,
}
Information about a Fairing.

The name field is an arbitrary name for a fairing. The kind field is a is an ord set of Kind structures. Rocket uses the values set in Kind to determine which callbacks from a given Fairing implementation to actually call.

Example

A simple Info structure that can be used for a Fairing that implements all four callbacks:

use rocket::fairing::{Info, Kind};

Info {
    name: "Example Fairing",
    kind: Kind::Attach | Kind::Launch | Kind::Request | Kind::Response
}

Fields

name: &'static str

The name of the fairing.

kind: Kind

A set representing the callbacks the fairing wishes to receive.