pub struct Kind(_);Expand description
A bitset representing the kinds of callbacks a
Fairing wishes to receive.
A fairing can request any combination of any of the following kinds of callbacks:
- Attach
- Launch
- Request
- Response
Two Kind structures can be ord together to represent a combination. For
instance, to represent a fairing that is both a launch and request fairing,
use Kind::Launch | Kind::Request. Similarly, to represent a fairing that
is only an attach fairing, use Kind::Attach.
Implementations
sourceimpl Kind
impl Kind
sourcepub fn is(self, other: Kind) -> bool
pub fn is(self, other: Kind) -> bool
Returns true if self is a superset of other. In other words,
returns true if all of the kinds in other are also in self.
Example
use rocket::fairing::Kind;
let launch_and_req = Kind::Launch | Kind::Request;
assert!(launch_and_req.is(Kind::Launch | Kind::Request));
assert!(launch_and_req.is(Kind::Launch));
assert!(launch_and_req.is(Kind::Request));
assert!(!launch_and_req.is(Kind::Response));
assert!(!launch_and_req.is(Kind::Launch | Kind::Response));
assert!(!launch_and_req.is(Kind::Launch | Kind::Request | Kind::Response));sourcepub fn is_exactly(self, other: Kind) -> bool
pub fn is_exactly(self, other: Kind) -> bool
Returns true if self is exactly other.
Example
use rocket::fairing::Kind;
let launch_and_req = Kind::Launch | Kind::Request;
assert!(launch_and_req.is_exactly(Kind::Launch | Kind::Request));
assert!(!launch_and_req.is_exactly(Kind::Launch));
assert!(!launch_and_req.is_exactly(Kind::Request));
assert!(!launch_and_req.is_exactly(Kind::Response));
assert!(!launch_and_req.is_exactly(Kind::Launch | Kind::Response));Trait Implementations
impl Copy for Kind