pub struct Accepted<R>(pub Option<R>);Expand description
Sets the status of the response to 202 (Accepted).
If a responder is supplied, the remainder of the response is delegated to it. If there is no responder, the body of the response will be empty.
Examples
A 202 Accepted response without a body:
use rocket::response::status;
let response = status::Accepted::<()>(None);A 202 Accepted response with a body:
use rocket::response::status;
let response = status::Accepted(Some("processing"));Tuple Fields
0: Option<R>Trait Implementations
sourceimpl<R> PartialEq<Accepted<R>> for Accepted<R>where
R: PartialEq<R>,
impl<R> PartialEq<Accepted<R>> for Accepted<R>where
R: PartialEq<R>,
sourceimpl<'r, R> Responder<'r> for Accepted<R>where
R: Responder<'r>,
impl<'r, R> Responder<'r> for Accepted<R>where
R: Responder<'r>,
Sets the status code of the response to 202 Accepted. If the responder is
Some, it is used to finalize the response.
impl<R> StructuralPartialEq for Accepted<R>