Struct rocket4::response::status::BadRequest
source · pub struct BadRequest<R>(pub Option<R>);Expand description
Sets the status of the response to 400 (Bad Request).
If a responder is supplied, the remainder of the response is delegated to it. If there is no responder, the body of the response will be empty.
Examples
A 400 Bad Request response without a body:
use rocket::response::status;
let response = status::BadRequest::<()>(None);A 400 Bad Request response with a body:
use rocket::response::status;
let response = status::BadRequest(Some("error message"));Tuple Fields
0: Option<R>Trait Implementations
sourceimpl<R> Clone for BadRequest<R>where
R: Clone,
impl<R> Clone for BadRequest<R>where
R: Clone,
sourcefn clone(&self) -> BadRequest<R>
fn clone(&self) -> BadRequest<R>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<R> Debug for BadRequest<R>where
R: Debug,
impl<R> Debug for BadRequest<R>where
R: Debug,
sourceimpl<R> PartialEq<BadRequest<R>> for BadRequest<R>where
R: PartialEq<R>,
impl<R> PartialEq<BadRequest<R>> for BadRequest<R>where
R: PartialEq<R>,
sourcefn eq(&self, other: &BadRequest<R>) -> bool
fn eq(&self, other: &BadRequest<R>) -> bool
sourceimpl<'r, R> Responder<'r> for BadRequest<R>where
R: Responder<'r>,
impl<'r, R> Responder<'r> for BadRequest<R>where
R: Responder<'r>,
Sets the status code of the response to 400 Bad Request. If the responder is
Some, it is used to finalize the response.
impl<R> StructuralPartialEq for BadRequest<R>