pub struct Data { /* private fields */ }Expand description
Type representing the data in the body of an incoming request.
This type is the only means by which the body of a request can be retrieved.
This type is not usually used directly. Instead, types that implement
FromData are used via code generation by specifying the
data = "<var>" route parameter as follows:
#[post("/submit", data = "<var>")]
fn submit(var: DataGuard) { /* ... */ }Above, DataGuard can be any type that implements FromData. Note that
Data itself implements FromData.
Reading Data
Data may be read from a Data object by calling either the
open() or peek() methods.
The open method consumes the Data object and returns the raw data
stream. The Data object is consumed for safety reasons: consuming the
object ensures that holding a Data object means that all of the data is
available for reading.
The peek method returns a slice containing at most 512 bytes of buffered
body data. This enables partially or fully reading from a Data object
without consuming the Data object.
Implementations
sourceimpl Data
impl Data
sourcepub fn open(self) -> DataStream ⓘ
pub fn open(self) -> DataStream ⓘ
Returns the raw data stream.
The stream contains all of the data in the body of the request,
including that in the peek buffer. The method consumes the Data
instance. This ensures that a Data type always represents all of
the data in a request.
Example
use rocket::Data;
fn handler(data: Data) {
let stream = data.open();
}sourcepub fn peek(&self) -> &[u8] ⓘ
pub fn peek(&self) -> &[u8] ⓘ
Retrieve the peek buffer.
The peek buffer contains at most 512 bytes of the body of the request.
The actual size of the returned buffer varies by web request. The
peek_complete method can be used to determine
if this buffer contains all of the data in the body of the request.
Example
use rocket::Data;
fn handler(data: Data) {
let peek = data.peek();
}sourcepub fn peek_complete(&self) -> bool
pub fn peek_complete(&self) -> bool
Returns true if the peek buffer contains all of the data in the body
of the request. Returns false if it does not or if it is not known if
it does.
Example
use rocket::Data;
fn handler(data: Data) {
if data.peek_complete() {
println!("All of the data: {:?}", data.peek());
}
}sourcepub fn stream_to<W>(self, writer: &mut W) -> Result<u64, Error>where
W: Write,
pub fn stream_to<W>(self, writer: &mut W) -> Result<u64, Error>where
W: Write,
A helper method to write the body of the request to any Write type.
This method is identical to io::copy(&mut data.open(), writer).
Example
use std::io;
use rocket::Data;
fn handler(mut data: Data) -> io::Result<String> {
// write all of the data to stdout
data.stream_to(&mut io::stdout())
.map(|n| format!("Wrote {} bytes.", n))
}sourcepub fn stream_to_file<P>(self, path: P) -> Result<u64, Error>where
P: AsRef<Path>,
pub fn stream_to_file<P>(self, path: P) -> Result<u64, Error>where
P: AsRef<Path>,
A helper method to write the body of the request to a file at the path
determined by path.
This method is identical to
io::copy(&mut self.open(), &mut File::create(path)?).
Example
use std::io;
use rocket::Data;
fn handler(mut data: Data) -> io::Result<String> {
data.stream_to_file("/static/file")
.map(|n| format!("Wrote {} bytes to /static/file", n))
}Trait Implementations
sourceimpl<'f> FromData<'f> for Data
impl<'f> FromData<'f> for Data
The identity implementation of FromData. Always returns Success.
type Owned = Data
type Owned = Data
FromData::transform(). Read moretype Borrowed = Data
type Borrowed = Data
FromData::from_data() when
FromData::transform() returns a Transform::Borrowed. Read moresourcefn transform(
_: &Request<'_>,
data: Data
) -> Transform<Outcome<<Data as FromData<'f>>::Owned, (Status, <Data as FromData<'f>>::Error), Data>, Outcome<<Data as FromData<'f>>::Owned, (Status, <Data as FromData<'f>>::Error), Data>>
fn transform(
_: &Request<'_>,
data: Data
) -> Transform<Outcome<<Data as FromData<'f>>::Owned, (Status, <Data as FromData<'f>>::Error), Data>, Outcome<<Data as FromData<'f>>::Owned, (Status, <Data as FromData<'f>>::Error), Data>>
sourcefn from_data(
_: &Request<'_>,
outcome: Transform<Outcome<<Data as FromData<'f>>::Owned, (Status, <Data as FromData<'f>>::Error), Data>, Outcome<&'f <Data as FromData<'f>>::Borrowed, (Status, <Data as FromData<'f>>::Error), Data>>
) -> Outcome<Data, (Status, <Data as FromData<'f>>::Error), Data>
fn from_data(
_: &Request<'_>,
outcome: Transform<Outcome<<Data as FromData<'f>>::Owned, (Status, <Data as FromData<'f>>::Error), Data>, Outcome<&'f <Data as FromData<'f>>::Borrowed, (Status, <Data as FromData<'f>>::Error), Data>>
) -> Outcome<Data, (Status, <Data as FromData<'f>>::Error), Data>
Self. Read moresourceimpl<'a, S, E> IntoOutcome<S, (Status, E), Data> for Result<S, E>
impl<'a, S, E> IntoOutcome<S, (Status, E), Data> for Result<S, E>